import logging
import socket
import concurrent.futures


def log_init(debug):
    if debug:
        level = 'debug'
    else:
        level = 'info'
    # 配置日志记录
    level = getattr(logging, level.upper(), logging.INFO)
    formatter = logging.Formatter('[%(asctime)s][%(levelname)s] %(message)s', '%Y-%m-%d %H:%M:%S')

    # 创建控制台日志处理器并设置格式
    console_handler = logging.StreamHandler()
    console_handler.setFormatter(formatter)

    # 获取根日志记录器并添加处理器
    logger = logging.getLogger()
    logger.setLevel(level)
    logger.addHandler(console_handler)


def check_port(host, port):
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    sock.settimeout(1)
    result = sock.connect_ex((host, port))
    sock.close()
    if result == 0:
        logging.info(f"Port {port} is open on {host}")
    else:
        logging.debug(f"Port {port} is closed on {host}")


def scan_ports(host, start_port, end_port):
    with concurrent.futures.ThreadPoolExecutor(max_workers=500) as executor:
        futures = []
        for port in range(start_port, end_port + 1):
            future = executor.submit(check_port, host, port)
            futures.append(future)

        # 等待所有任务完成
        for future in concurrent.futures.as_completed(futures):
            try:
                future.result()
            except Exception as e:
                print(f"An error occurred: {str(e)}")


def main():
    log_init(False)
    host = 'me.mxin.co'
    start_port = 1
    end_port = 65535
    scan_ports(host, start_port, end_port)


if __name__ == "__main__":
    main()
